/**************************************************************************
 * scanerrorinterface.h - class declaration of ScanErrorInterface class.
 * Copyright (C) 2003-2005 Lexmark International, Inc.
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License
 * as published by the Free Software Foundation; either version 2
 * of the License, or (at your option) any later version.
 *
 * This program is  distributed in the hope that it will  be useful,
 * but WITHOUT ANY WARRANTY;  without  even the implied  warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * General Public License at http://www.gnu.org/licenses/licenses.html
 * for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation,Inc.,59 Temple Place - Suite 330,Boston,MA 02111-1307,USA.
 *
 **************************************************************************/
#ifndef SCAN_ERROR_INTERFACE_H
#define SCAN_ERROR_INTERFACE_H

/**
 * This is an abstract class that is responsible for implementing dispatching mechanism for reporting printer errors that occurred during a print job.
 *  This also contains the function that asks/receives user decision from the client whether to continue or abort the print job as a result of the reported errors.
 *
 */
class ScanErrorInterface{

public:
		///Enumerated Error messages that can be passed to the GUI or application.
		/**
		 *
		 * PrinterError defines an enumerated list of the various error messages that can be reported to the GUI.
		 * Some of these errors are critical which includes communication errors, paper jam, carrier stall, etc.
		 * while others can be ignored during printing (top cover open, etc.).
		 *
		 */
	enum ScannerError
	{
		ERR_NONE,			/**< Operation results in No errors. */
		ERR_COMMUNICATION_ERROR,	/**< Scanner gets communication errors. This may be a result of
						  an offline condition or the connection to the scanner is
						  broken. */
		ERR_DEVICE_WARMING_UP, 		 /**< Scanner is warming up.(For CCD scanners only) */
		ERR_SCANNER_NOT_LOCKED,		 /**< Device is busy. Scanner can't be locked. */
		ERR_DEVICE_OFF,  		 /**< Device is off */
		ERR_COPIER_NOT_LOCKED,		 /**< Device is busy. Copier can't be locked. */
		ERR_SCAN_STOPPED,		/**< Scanning was stopped from device(AIO) */
		ERR_MEMORY_OUT,		/**< An out of memory error occured */
		ERR_UNEXPECTED_ERROR,		/**< An unexpected error occured */
		ERR_ADF_PAPER_JAM			/**Paper jam on ADF"**/
	};

		///The response that can be passed to the driver after an error is reported.
		/**
		 * UserDecision is an enumerated list of reponses that can be queried from the GUI or application whether
		 * the printing is to continue or aborted.
		 *
		 */
		enum UserDecision
		{
			ABORT,				/**< Scan Job aborted */
			CONTINUE,			/**< Scan Job is to continue after errors */
			NOT_ANSWERED			/**< The error prompt to the application or GUI wasn't answered */
		};

public:
	/** Callback function to notify the client (GUI or an application) any printer errors occurred in the driver during printing.
	 *   This function is called by an EI_Alarm of the ErrorInterface class that is called by the print system when a printer error occurred.
	 *
	 * @return none
	 * @param error (in) Type of PrinterError
	 *
	 */
	virtual void ReportError(ScannerError error) = 0;

	/** Callback function that will query the client for a decision whether to abort or continue the print job .
	 *  This function is called by an EI_IsJobCancelled function of the ErrorInterface class which is called after the EI_Alarm function.
     *
	 * @return UserDecision Possible values are: 0=ABORT, 1=CONTINUE, or 2=NOT_ANSWERED
	 * @param none
	 *
	 */
	virtual UserDecision GetUserDecision() = 0;

}; // class ScanErrorInterface;
#endif // SCAN_ERROR_Interface_H
